BlockDownloaderConfig

Struct BlockDownloaderConfig 

pub struct BlockDownloaderConfig {
    pub buffer_bytes: usize,
    pub in_progress_queue_bytes: usize,
    pub check_client_pool_interval: Duration,
    pub target_batch_bytes: usize,
    pub initial_batch_len: usize,
}
The block downloader config.

Fields

buffer_bytes: usize

The size in bytes of the buffer between the block downloader and the place which is consuming the downloaded blocks.

in_progress_queue_bytes: usize

The size of the in progress queue (in bytes) at which we stop requesting more blocks.

check_client_pool_interval: Duration

The Duration between checking the client pool for free peers.

target_batch_bytes: usize

The target size of a single batch of blocks (in bytes).

initial_batch_len: usize

The initial amount of blocks to request (in number of blocks)