pub struct ChainEntry<N: NetworkZone> {
pub ids: Vec<[u8; 32]>,
pub peer: InternalPeerID<N::Addr>,
pub handle: ConnectionHandle,
}Expand description
A new chain entry to add to our chain tracker.
Fields
ids: Vec<[u8; 32]>A list of block IDs.
peer: InternalPeerID<N::Addr>The peer who told us about this chain entry.
handle: ConnectionHandleThe peer who told us about this chain entry’s handle